@@ -343,6 +343,10 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terrag
     help='Include the terraform lock file',
     show_default=True
     )
+@click.option('--auto-approve', '-a', is_flag=True, default=False,
+    help='Do not ask for confirmation before applying planned changes (where applicable)',
+    show_default=True
+    )
 @click.option('--verbose', '-v', is_flag=True, default=False,
     help='Verbose printing',
     show_default=True
@@ -356,7 +360,10 @@ def analyze(verbose, dry_run, exclude_external_dependencies, working_dir, terrag
     help='Working directory, when omitted the current directory is used',
     )
 @click.version_option(version=__version__)
-def deploy(source_domain, source_stage, target_domain, target_stage, module, verbose, dry_run, clean_up, include_lock_file, working_dir):
+def deploy(
+    source_domain, source_stage, target_domain, target_stage, module, auto_approve,
+    verbose, dry_run, clean_up, include_lock_file, working_dir
+    ):
     """ Deploys the terragrunt config files from one stage to another (and possibly to a different domain) """
 
     check_latest_version()
@@ -368,6 +375,7 @@ def deploy(source_domain, source_stage, target_domain, target_stage, module, ver
         target_domain=target_domain,
         target_stage=target_stage,
         module=module,
+        auto_approve=auto_approve,
         dry_run=dry_run,
         clean_up=clean_up,
         include_lock_file=include_lock_file,
@@ -401,6 +409,10 @@ def deploy(source_domain, source_stage, target_domain, target_stage, module, ver
     help='Include the terraform lock file',
     show_default=True
     )
+@click.option('--auto-approve', '-a', is_flag=True, default=False,
+    help='Do not ask for confirmation before applying planned changes (where applicable)',
+    show_default=True
+    )
 @click.option('--verbose', '-v', is_flag=True, default=False,
     help='Verbose printing',
     show_default=True
@@ -414,7 +426,10 @@ def deploy(source_domain, source_stage, target_domain, target_stage, module, ver
     help='Working directory, when omitted the current directory is used',
     )
 @click.version_option(version=__version__)
-def git_deploy(git_repo, source_directory, target_domain, target_stage, verbose, dry_run, include_lock_file, working_dir):
+def git_deploy(
+    git_repo, source_directory, target_domain, target_stage,
+    auto_approve, verbose, dry_run, include_lock_file, working_dir
+    ):
     """ [experimental] Deploys the terragrunt config files from a git repository """
 
     check_latest_version()
@@ -425,6 +440,7 @@ def git_deploy(git_repo, source_directory, target_domain, target_stage, verbose,
         source_directory=source_directory,
         target_domain=target_domain,
         target_stage=target_stage,
+        auto_approve=auto_approve,
         dry_run=dry_run,
         include_lock_file=include_lock_file,
         working_dir=working_dir,
