@@ -38,7 +38,11 @@ class Printer():
         return self._print_verbose
 
     def line(self):
-        width, _ = os.get_terminal_size()
+        width = 80
+        try:
+          width, _ = shutil.get_terminal_size() 
+        except OSError as e:
+          pass
         click.secho("-" * width, file=sys.stderr)
 
     def header(self, msg, print_line_before=False, print_line_after=False):
@@ -218,6 +222,88 @@ class TgWrap():
 
         return graph
 
+    def _analyze_results(self, rc, messages):
+        """ Checks for errors """
+
+        error = False
+
+        messages = messages.lower()
+
+        if rc.returncode != 0 or 'error' in messages:
+            error = True
+
+        return error
+
+    def _run_graph_step(self, command, working_dir, directory, collect_output_file, dry_run):
+        """ Runs a step in the graph """
+
+        stop_processing = False
+
+        # if we have a specific working dir, and the dir is relative, combine the two
+        if working_dir and not os.path.isabs(directory):
+            directory = os.path.join(os.path.abspath(working_dir), directory)
+            self.printer.verbose(f'Executing in directory: {working_dir}')
+
+        self.printer.header(
+            f'\n\nStart processing directory: {directory}\n\n',
+            print_line_before=True,
+            )
+
+        try:
+            if dry_run:
+                self.printer.warning(
+                    'In dry run mode, no real actions are executed!!'
+                    )
+            else:
+                if collect_output_file:
+                    collect_output_file.write(f'{directory}{self.SEPARATOR}')
+                    collect_output_file.flush()
+
+                messages = ""
+
+                with tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=False) as f:
+                    self.printer.verbose(f"Opened temp file for error collection: {f.name}")
+                    rc = {'returncode': 0}
+                    rc = subprocess.run(
+                        shlex.split(command),
+                        text=True,
+                        cwd=directory,
+                        stdout=collect_output_file if collect_output_file else sys.stdout,
+                        stderr=f,
+                    )
+                    self.printer.verbose(rc)
+
+                with open(f.name, 'r') as f:
+                    messages = f.read()
+
+                error = self._analyze_results(
+                    rc=rc,
+                    messages=messages,
+                    )
+
+                if error:
+                    raise Exception(
+                        f'An error situation detected while processing the terragrunt dependencies graph in directory {directory}'
+                        )
+                else:
+                    self.printer.success(
+                        f'Directory {directory} processed successfully',
+                    )
+
+        except FileNotFoundError:
+            self.printer.warning(f'Directory {directory} not found, continue')
+        except Exception as e:
+            self.printer.error(f"Error occurred:\n{str(e)}")
+            self.printer.error("Full stack:", print_line_before=True)
+            self.printer.normal(messages, print_line_after=True)
+            self.printer.normal(f"Directory {directory} failed!")
+
+            stop_processing = True
+        finally:
+            os.remove(f.name)
+
+        return stop_processing
+
     def _run_di_graph(
         self, command, exclude_external_dependencies, dry_run,
         ask_for_confirmation=False, collect_output_file=None,
@@ -255,73 +341,22 @@ class TgWrap():
 
             if command:
                 for directory in group:
-                    # if we have a specific working dir, and the dir is relative, combine the two
-                    if working_dir and not os.path.isabs(directory):
-                        directory = os.path.join(os.path.abspath(working_dir), directory)
-                        self.printer.verbose(f'Executing in directory: {working_dir}')
+                    stop_processing = self._run_graph_step(
+                        command=command,
+                        working_dir=working_dir,
+                        directory=directory,
+                        collect_output_file=collect_output_file,
+                        dry_run=dry_run,
+                    )
 
-                    self.printer.header(
-                        f'\n\nStart processing directory: {directory}\n\n',
-                        print_line_before=True,
-                        print_line_after=True,
-                        )
-
-                    if dry_run:
-                        self.printer.warning(
-                            'In dry run mode, no real actions are executed!!'
-                            )
-                    else:
-                        try:
-                            if collect_output_file:
-                                collect_output_file.write(f'{directory}{self.SEPARATOR}')
-                                collect_output_file.flush()
-
-                            messages = ""
-
-                            with tempfile.NamedTemporaryFile(mode='w+', prefix='tgwrap-', delete=False) as f:
-                                self.printer.verbose(f"Opened temp file for error collection: {f.name}")
-                                rc = {'returncode': 0}
-                                rc = subprocess.run(
-                                    shlex.split(command),
-                                    text=True,
-                                    cwd=directory,
-                                    stdout=collect_output_file if collect_output_file else sys.stdout,
-                                    stderr=f,
-                                )
-                                self.printer.verbose(rc)
-
-                            with open(f.name, 'r') as f:
-                                messages = f.read()
-
-                            if rc.returncode != 0 or 'error' in messages.lower():
-                                raise Exception(
-                                    f'An error situation detected while processing the terragrunt dependencies graph in directory {directory}'
-                                    )
-                            else:
-                                self.printer.warning(
-                                    f'Directory {directory} processed successfully',
-                                    print_line_before=True,
-                                    print_line_after=True,
-                                )
-
-                        except FileNotFoundError:
-                            self.printer.warning(f'Directory {directory} not found, continue')
-                        except Exception as e:
-                            self.printer.error(f"Error occurred:\n{str(e)}")
-                            self.printer.error("Full stack:", print_line_before=True)
-                            self.printer.normal(messages, print_line_after=True)
-                            self.printer.normal(f"Directory {directory} failed!")
-
-                            stop_processing = True
-                            break
-                        finally:
-                            os.remove(f.name)
+                    if stop_processing:
+                        break
 
             if stop_processing:
                 break
 
     def _run_sync(
-        self, source_path, target_path, source_stage, target_stage,
+        self, source_path, target_path, source_stage, target_stage, auto_approve,
         include_lock_file, dry_run, clean_up, git_source_path=None, source_domain=None,
         ):
         """ Run a sync copying files from a source to a target path """
@@ -367,9 +402,11 @@ class TgWrap():
             self.printer.normal(f"from: {git_source_path if git_source_path else source_path}")
             self.printer.normal(f"to:   {target_path}")
             self.printer.verbose(f"Using command:\n$ {cmd}")
-            response = input("\nDo you want to continue? (y/n) ")
-            if response.lower() != "y":
-                sys.exit(1)
+
+            if not auto_approve:
+                response = input("\nDo you want to continue? (y/n) ")
+                if response.lower() != "y":
+                    sys.exit(1)
 
             rc = subprocess.run(shlex.split(cmd))
             self.printer.verbose(rc)
@@ -412,8 +449,8 @@ class TgWrap():
             self.printer.verbose(rc)
 
     def run_all(self, command, debug, dry_run, no_lock, update_source,
-        exclude_external_dependencies, step_by_step, auto_approve, working_dir,
-        limit_parallelism, terragrunt_args):
+        exclude_external_dependencies, step_by_step, auto_approve, 
+        working_dir, limit_parallelism, terragrunt_args):
         """ Executes a terragrunt command across multiple modules """
 
         self.printer.verbose(f"Attempting to execute 'run-all {command}'")
@@ -440,9 +477,9 @@ class TgWrap():
             self._run_di_graph(
                 command=cmd,
                 exclude_external_dependencies=exclude_external_dependencies,
-                dry_run=dry_run,
                 working_dir=working_dir,
                 ask_for_confirmation=(not auto_approve),
+                dry_run=dry_run,
             )
         else:
             if dry_run:
@@ -559,7 +596,7 @@ class TgWrap():
                         self.printer.verbose(f"Opened temp file for terrasafe input: {json_file.name}")
 
                         json_file.write(plan_file)
-                        json_file.flush
+                        json_file.flush()
 
                         # Check if the "TERRASAFE_CONFIG" environment variable is set
                         env_var = "TERRASAFE_CONFIG"
@@ -581,16 +618,18 @@ class TgWrap():
                                 )
                             if output.returncode != 0:
                                 ts_validation_successful = False
-                                self.printer.error(output.stdout)
+                                self.printer.error(output)
                             elif '0 unauthorized' in output.stdout:
                                 self.printer.success(output.stdout)
-
                     except json.decoder.JSONDecodeError as e:
                         raise Exception(
                             f"Planfile for {module} was no proper json, further analysis not possible."
                             ) from e
                     finally:
-                        json_file.close()
+                        try:
+                            json_file.close()
+                        except UnboundLocalError:
+                            pass
         finally:
             os.remove(f.name)
 
@@ -599,7 +638,7 @@ class TgWrap():
 
     def deploy(
         self, source_stage, target_stage, source_domain, target_domain, module,
-        dry_run, clean_up, include_lock_file, working_dir, 
+        auto_approve, dry_run, clean_up, include_lock_file, working_dir, 
         ):
         """ Deploys the terragrunt config files from one stage to another (and possibly to a different domain) """
     
@@ -625,13 +664,14 @@ class TgWrap():
             source_stage=source_stage,
             target_stage=target_stage,
             include_lock_file=include_lock_file,
+            auto_approve=auto_approve,
             dry_run=dry_run,
             clean_up=clean_up,
         )
 
     def git_deploy(
         self, git_repo, source_directory, target_domain, target_stage,
-        dry_run, include_lock_file, working_dir, 
+        auto_approve, dry_run, include_lock_file, working_dir, 
         ):
         """ Deploys the terragrunt config files from a git repository """
 
@@ -713,6 +753,7 @@ class TgWrap():
                 source_stage=source_stage,
                 target_stage=target_stage,
                 include_lock_file=include_lock_file,
+                auto_approve=auto_approve,
                 dry_run=dry_run,
                 clean_up=False,
             )
